<?php
/**
 * Plugin Name: wp-scripts Plugin
 * Description: Test plugin
 * Author: Liip AG
 * Author URI: https://liip.ch
 * Version: 1.0.0
 * License: GPL2+
 * License URI: https://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: wp-scripts-plugin
 * Domain Path: /languages/
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Define WP_SCRIPTS_PLUGIN_FILE.
if ( ! defined( 'WP_SCRIPTS_PLUGIN_FILE' ) ) {
	define( 'WP_SCRIPTS_PLUGIN_FILE', __FILE__ );
}

if ( ! defined( 'WP_SCRIPTS_PLUGIN_ABSPATH' ) ) {
	define( 'WP_SCRIPTS_PLUGIN_ABSPATH', trailingslashit( dirname( WP_SCRIPTS_PLUGIN_FILE ) ) );
}

// Hook: Editor assets.
add_action( 'enqueue_block_editor_assets', 'test_enqueue_block_editor_assets', 99 );

function test_enqueue_block_editor_assets() {
	$assets_dir = WP_SCRIPTS_PLUGIN_ABSPATH . 'build/';
	$assets_url = esc_url( trailingslashit( plugins_url( '/build/', WP_SCRIPTS_PLUGIN_FILE ) ) );

	// Scripts.
	$index_path = $assets_dir . 'index.js';
	$index_url = esc_url( $assets_url ) . 'index.js';
	$index_asset_file = $assets_dir . 'index.asset.php';
	$index_asset = file_exists( $index_asset_file )
		? require_once $index_asset_file
		: null;
	$index_dependencies = isset( $index_asset['dependencies'] ) ? $index_asset['dependencies'] : array();
	$index_version = isset( $index_asset['version'] ) ? $index_asset['version'] : filemtime( $index_path );

	wp_enqueue_script(
		'test-js', // Handle.
		$index_url,
		$index_dependencies,
		$index_version,
		true // Enqueue the script in the footer.
	);

	// Styles.
	wp_enqueue_style(
		'test-editor-styles', // Handle.
		esc_url( $assets_url ) . 'index.css', // Block editor CSS.
		array( 'wp-edit-blocks' ), // Dependency to include the CSS after it.
		'1.0.0'
	);
}
